gg_timeline library

This libray allows you to manage arbitrary data like on a timeline.

Classes

ExampleTimeline
A example timeline that can be used for test purposes.
GgTimeline<T>
The baseclass of timelines with items of type T
GgTimelineItem<T>
An item on an GgTimelin

Constants

exampleGgTimelineItem → const GgTimelineItem<int>
An example timeline item used for tests

Functions

exampleGgTimeline() GgTimeline<double>
Create a new ExampleTimeline instance.